Module error

Module error 

The error type shared by every streaming format, in both directions.

Structs

StreamError
The error that may occur while encoding or decoding a streamed HTTP body.

Enums

StreamErrorKind
The kind of error that occurred.