#[non_exhaustive]pub struct DecodeOptions {
pub max_obj_len: usize,
pub buf_capacity: usize,
}Expand description
Limits applied while decoding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_obj_len: usizeMaximum length of a single decoded object.
buf_capacity: usizeInitial capacity of the read buffer.
Implementations
Sourceimpl DecodeOptions
impl DecodeOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Options with no per-object limit.
Appropriate for a client reading a server it chose. A server reading untrusted input
should set max_obj_len instead.
Sourcepub fn max_obj_len(self, value: usize) -> Self
pub fn max_obj_len(self, value: usize) -> Self
Set the maximum length of a single decoded object.
Sourcepub fn buf_capacity(self, value: usize) -> Self
pub fn buf_capacity(self, value: usize) -> Self
Set the initial capacity of the read buffer.