pub struct CsvFrameConfig {
pub delimiter: u8,
pub quote: u8,
pub double_quote: bool,
pub escape: Option<u8>,
pub terminator: Terminator,
}Available on crate feature
csv only.Expand description
How to frame CSV records.
Fields
delimiter: u8Field delimiter.
quote: u8Quote character.
double_quote: boolWhether a doubled quote character is an escaped quote.
escape: Option<u8>Escape character, if escaping is by prefix rather than by doubling.
terminator: TerminatorRecord terminator.