JsonArrayCodec

Struct JsonArrayCodec 

pub struct JsonArrayCodec<T> { /* private fields */ }
Available on crate feature json only.
A Decoder that yields the elements of a JSON array.

Implementations

Source

impl<T> JsonArrayCodec<T>

pub fn new_with_max_length(max_length: usize) -> Self

A codec that rejects any single element longer than max_length bytes.