JsonNewLineCodec

Struct JsonNewLineCodec 

pub struct JsonNewLineCodec<T> { /* private fields */ }
Available on crate feature json only.
A Decoder that yields one deserialised item per line.

Implementations

Source

impl<T> JsonNewLineCodec<T>

pub fn new_with_max_length(max_length: usize) -> Self

A codec that rejects any single line longer than max_length bytes.