pub struct JsonArrayCodec<T> { /* private fields */ }Available on crate feature
json only.Expand description
A Decoder that yields the elements of a JSON array.
Implementations
Sourceimpl<T> JsonArrayCodec<T>
impl<T> JsonArrayCodec<T>
Sourcepub fn new_with_max_length(max_length: usize) -> Self
pub fn new_with_max_length(max_length: usize) -> Self
A codec that rejects any single element longer than max_length bytes.