pub struct JsonNewLineCodec<T> { /* private fields */ }Available on crate feature
json only.Expand description
A Decoder that yields one deserialised item per line.
Implementations
Sourceimpl<T> JsonNewLineCodec<T>
impl<T> JsonNewLineCodec<T>
Sourcepub fn new_with_max_length(max_length: usize) -> Self
pub fn new_with_max_length(max_length: usize) -> Self
A codec that rejects any single line longer than max_length bytes.